@@ -20,6 +20,10 @@ class RunFeature(Feature):
     def name(self) -> str:
         return "binary"
 
+    @property
+    def dependencies(self) -> Iterable[str]:
+        return ["core"]
+
     @property
     def schema(self) -> ClassVar[FeatureSchema]:
         return RunSchema
